@@ -1,18 +1,17 @@
 ## File Name: invariance.alignment.R
-## File Version: 3.693
+## File Version: 3.698
 
 
 invariance.alignment <- function( lambda, nu, wgt=NULL,
-    align.scale=c(1,1), align.pow=c(.5,.5), eps=1e-4,
+    align.scale=c(1,1), align.pow=c(.5,.5), eps=1e-3,
     psi0.init=NULL, alpha0.init=NULL, center=FALSE, optimizer="optim",
-    fixed=TRUE, ... )
+    fixed=NULL, ... )
 {
     CALL <- match.call()
     s1 <- Sys.time()
     type <- "AM"
     align.pow0 <- align.pow
     align.pow <- align.pow / 2
-    reparam <- ! fixed
 
     #-- labels for groups and items
     lambda <- invariance_alignment_proc_labels(x=lambda)
@@ -25,6 +24,10 @@ invariance.alignment <- function( lambda, nu, wgt=NULL,
         wgt <- 1+0*nu
     }
 
+    #- choose fixed value
+    fixed <- invariance_alignment_choose_fixed(fixed=fixed, G=G, Gmax=8)
+    reparam <- ! fixed
+
     W1 <- dim(wgt)
     wgtM <- matrix( colSums(wgt,na.rm=TRUE), nrow=W1[1], ncol=W1[2], byrow=TRUE )
     # wgtM <- matrix( 1, nrow=W1[1], ncol=W1[2], byrow=TRUE )
