@@ -1,12 +1,14 @@
 ## File Name: sirt_dmvnorm_discrete.R
-## File Version: 0.03
+## File Version: 0.06
 
-sirt_dmvnorm_discrete <- function(x, mean=NULL, sigma=NULL, as_matrix=FALSE, ...)
+sirt_dmvnorm_discrete <- function(x, mean=NULL, sigma=NULL, as_matrix=FALSE,
+    eps=0, ...)
 {
     y <- sirt_dmvnorm(x=x, mean=mean, sigma=sigma, ... )
     if (as_matrix){
         y <- matrix(y, nrow=length(y), ncol=1)
     }
+    y <- y + eps
     y <- y / sum(y)
     return(y)
 }
